fiona Package
=============

:mod:`fiona` Package
--------------------

.. automodule:: fiona.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`collection` Module
------------------------

.. automodule:: fiona.collection
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`crs` Module
-----------------

.. automodule:: fiona.crs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`errors` Module
--------------------

.. automodule:: fiona.errors
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ogrext` Module
--------------------

.. automodule:: fiona.ogrext
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ogrinit` Module
---------------------

.. automodule:: fiona.ogrinit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ogropts` Module
---------------------

.. automodule:: fiona.ogropts
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rfc3339` Module
---------------------

.. automodule:: fiona.rfc3339
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tool` Module
------------------

.. automodule:: fiona.tool
    :members:
    :undoc-members:
    :show-inheritance:

